#/bin/sh

# don't launch directly this script
# use 'make install-demo' to do so

set -e

PGBIN=/usr/lib/postgresql15/bin
PGSHARE=/usr/share/postgresql15/contrib/postgis-1.5
PGUSER=postgres
SHP2PGSQL=/usr/lib/postgresql/bin/shp2pgsql
DB=tinyows_demo

if [ -d /usr/share/postgresql15/contrib/postgis-3.0 ]; then
	PGSHARE=/usr/share/postgresql15/contrib/postgis-3.0
elif [ -d /usr/share/postgresql15/contrib/postgis-2.5 ]; then
	PGSHARE=/usr/share/postgresql15/contrib/postgis-2.5
elif [ -d /usr/share/postgresql15/contrib/postgis-2.4 ]; then
	PGSHARE=/usr/share/postgresql15/contrib/postgis-2.4
elif [ -d /usr/share/postgresql15/contrib/postgis-2.3 ]; then
	PGSHARE=/usr/share/postgresql15/contrib/postgis-2.3
elif [ -d /usr/share/postgresql15/contrib/postgis-2.2 ]; then
	PGSHARE=/usr/share/postgresql15/contrib/postgis-2.2
elif [ -d /usr/share/postgresql15/contrib/postgis-2.1 ]; then
	PGSHARE=/usr/share/postgresql15/contrib/postgis-2.1
elif [ -d /usr/share/postgresql15/contrib/postgis-2.0 ]; then
	PGSHARE=/usr/share/postgresql15/contrib/postgis-2.0
elif [ -d /usr/share/postgresql15/contrib/postgis-1.5 ]; then
	PGSHARE=/usr/share/postgresql15/contrib/postgis-1.5
else
	echo "Unable to find PostGIS dir in /usr/share/postgresql15/contrib/" && exit 1
fi

echo "Create Spatial Database: $DB"
su $PGUSER -c "$PGBIN/dropdb $DB > /dev/null 2> /dev/null || /bin/true"
su $PGUSER -c "$PGBIN/createdb $DB"
if test -f "$PGBIN/createlang"; then
    su $PGUSER -c "$PGBIN/createlang plpgsql $DB"
fi
su $PGUSER -c "$PGBIN/psql $DB < $PGSHARE/postgis.sql"
su $PGUSER -c "$PGBIN/psql $DB < $PGSHARE/spatial_ref_sys.sql"

echo "Import layer data: world" 
$SHP2PGSQL -s 4326 -I demo/world.shp world > _world.sql
su $PGUSER -c "$PGBIN/psql $DB < _world.sql"

echo "Import layer data: france_dept" 
$SHP2PGSQL -s 27582 -I -W latin1 demo/france.shp france > _france.sql
su $PGUSER -c "$PGBIN/psql $DB < _france.sql"

echo "Import non spatial layer"
echo "CREATE TABLE geometry_less(id SERIAL PRIMARY KEY, intcol INTEGER, textcol TEXT);" > _geometry_less.sql
echo "INSERT INTO geometry_less (intcol, textcol) VALUES (123, 'foo');" >> _geometry_less.sql
su $PGUSER -c "$PGBIN/psql $DB < _geometry_less.sql"

rm _world.sql _france.sql _geometry_less.sql
